@@ -27,6 +27,23 @@ G_BEGIN_DECLS
 GType gtk_source_completion_activation_get_type (void);
 G_END_DECLS
 
+#include <gtksourceview/gtksourcefileloader.h>
+G_BEGIN_DECLS
+#define GTK_SOURCE_TYPE_FILE_LOADER_ERROR gtk_source_file_loader_error_get_type()
+GType gtk_source_file_loader_error_get_type (void);
+G_END_DECLS
+
+#include <gtksourceview/gtksourcefilesaver.h>
+G_BEGIN_DECLS
+#define GTK_SOURCE_TYPE_FILE_SAVER_ERROR gtk_source_file_saver_error_get_type()
+GType gtk_source_file_saver_error_get_type (void);
+G_END_DECLS
+
+G_BEGIN_DECLS
+#define GTK_SOURCE_TYPE_FILE_SAVER_FLAGS gtk_source_file_saver_flags_get_type()
+GType gtk_source_file_saver_flags_get_type (void);
+G_END_DECLS
+
 #include <gtksourceview/gtksourcegutterrenderer.h>
 G_BEGIN_DECLS
 #define GTK_SOURCE_TYPE_GUTTER_RENDERER_STATE gtk_source_gutter_renderer_state_get_type()
@@ -38,6 +55,22 @@ G_BEGIN_DECLS
 GType gtk_source_gutter_renderer_alignment_mode_get_type (void);
 G_END_DECLS
 
+#include <gtksourceview/gtksourcetypes.h>
+G_BEGIN_DECLS
+#define GTK_SOURCE_TYPE_NEWLINE_TYPE gtk_source_newline_type_get_type()
+GType gtk_source_newline_type_get_type (void);
+G_END_DECLS
+
+G_BEGIN_DECLS
+#define GTK_SOURCE_TYPE_COMPRESSION_TYPE gtk_source_compression_type_get_type()
+GType gtk_source_compression_type_get_type (void);
+G_END_DECLS
+
+G_BEGIN_DECLS
+#define GTK_SOURCE_TYPE_BACKGROUND_PATTERN_TYPE gtk_source_background_pattern_type_get_type()
+GType gtk_source_background_pattern_type_get_type (void);
+G_END_DECLS
+
 #include <gtksourceview/gtksourceview.h>
 G_BEGIN_DECLS
 #define GTK_SOURCE_TYPE_VIEW_GUTTER_POSITION gtk_source_view_gutter_position_get_type()
